@@ -75,8 +75,9 @@ function(e1,e2){
 setMethod("/", c("numeric",
                  "AcDcLcDistribution"),
 function(e1,e2){
-         e2s <- as.character(deparse(match.call(
-                call = sys.call(sys.parent(1)))$e2))
+  if (is((e2s <- as.character(deparse(match.call(
+                call = sys.call(sys.parent(1)))$e2))), "try-error"))
+      e2s <- "e2"
 
  e2 <- .ULC.cast(e2)
 
@@ -124,8 +125,10 @@ function(e1,e2){
 setMethod("/", c("AcDcLcDistribution",
                  "AcDcLcDistribution"),
 function(e1,e2){
-         e2s <- as.character(deparse(match.call(
-                call = sys.call(sys.parent(1)))$e2))
+  if (is((e2s <- as.character(deparse(match.call(
+                call = sys.call(sys.parent(1)))$e2))), "try-error"))
+      e2s <- "e2"
+
 #         if( is(e2,"AbscontDistribution"))
 #             e2 <- as(as(e2,"AbscontDistribution"), "UnivarLebDecDistribution")
 
