@@ -14,14 +14,14 @@ setMethod("liesInSupport", signature(object = "DiscreteDistribution",
 setMethod("liesInSupport", signature(object = "AbscontDistribution",
                                      x = "numeric"),
     function(object, x){ 
-        if(!is.nan(q(object)(0)))
-            low <- q(object)(0)
+        if(!is.nan(q.l(object)(0)))
+            low <- q.l(object)(0)
         else
-            low <- q(object)(10*.Machine$double.eps)
-        if(!is.nan(q(object)(1)))
-            upp <- q(object)(1)
+            low <- q.l(object)(10*.Machine$double.eps)
+        if(!is.nan(q.l(object)(1)))
+            upp <- q.l(object)(1)
         else
-            upp <- q(object)(1-10*.Machine$double.eps)
+            upp <- q.l(object)(1-10*.Machine$double.eps)
 
         (x >= low)&(x <= upp)
     })
